#!/usr/bin/perl -w

###########################################################################
#
# gs2html.pl -- convert various documents to HTML
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 1999 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

# Convert Microsoft Word, and Adobe PDF to HTML using the
# appropriate specialist convert util


BEGIN {
    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
    unshift (@INC, "$ENV{'GSDLHOME'}/perllib");

}

use parsargv;
use util;
use Cwd;
use File::Basename;


sub print_usage
{

    print STDERR "Usage: $0 [-t doc|pdf] filename\n";
    exit(1);
}


sub main
{
    my (@ARGV) = @_;

    my ($input_type,$verbose);

    if (!parsargv::parse(\@ARGV,
			 'type/(doc|pdf)/', \$input_type,
			 'verbose/\d+/0',   \$verbose))
    {
	print_usage();
    }

    if (scalar(@ARGV!=1))
    {
	print_usage();
    }
    
    my $input_filename = $ARGV[0];
    if (!-r $input_filename)
    {
	print STDERR "Error: unable to open $input_filename for reading\n";
	exit(1);
    }

    my ($tailname,$dirname,$suffix) 
	= File::Basename::fileparse($input_filename,'\..+');
    my $output_filename = &util::filename_cat($dirname,"$tailname.html");

    if ($input_type eq "")
    {
	$input_type = substr($suffix,1,length($suffix)-1);
    }
    
    # Change to temporary working directory
    my $stored_dir = cwd();
    chdir ($dirname) || die "Unable to change to directory $dirname";

    
    # Select convert utility
    my $cmd = "";
    if (!defined $input_type)
    {
	print STDERR "Error: No filename extension or input type defined\n";
	exit(1);
    }
    elsif ($input_type eq "doc")
    {
	my $wv_cfgfile = &util::filename_cat($ENV{'GSDLHOME'},"etc","wvhtml.xml");
	$cmd = "( echo Processing ; wvHtml --config $wv_cfgfile \"$input_filename\" 2>&1 > \"$output_filename\" )";
	$cmd .= " | fgrep -v wvWarning" if ($verbose<3);
	$cmd .= " | fgrep -v wvError" if ($verbose<5);
    }
    elsif ($input_type eq "pdf")
    {
	$cmd = "pdftohtml  -F -d $dirname -o \"$tailname.html\" \"$input_filename\"";
	$cmd .= " >/dev/null" if ($verbose<3);
    }
    else
    {
	print STDERR "Error: Unable to convert to type '$input_type'\n";
	exit(1);
    }

    if (system($cmd)>0)
    {
	print STDERR "Error: failed to execute $cmd: $!\n";
	exit(1);
    }

    # restore to original working directory
    chdir ($stored_dir) || die "Unable to return to directory $stored_dir";

}



&main(@ARGV)

